# ProvenanceResultResponseResultParameters

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**project** | [**ProjectDef**](ProjectDef.md) |  |
**whitelisted_sources** | **list[str]** | Python package indexes whitelisted | [optional]

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

